var cacheToCss = require('./cache-to-css');
var cacheToStylesheets = require('./cache-to-stylesheets');
var generateHtmlString = require('./generate-html-string');
var StyletronCore = require('styletron-core');

/**
 * StyletronServer
 * @packagename styletron-server
 * @extends StyletronCore
 */
var StyletronServer = (function (StyletronCore) {
  function StyletronServer() {
    StyletronCore.call(this);
    this.injectionCallCount = 0;
  }

  if ( StyletronCore ) StyletronServer.__proto__ = StyletronCore;
  StyletronServer.prototype = Object.create( StyletronCore && StyletronCore.prototype );
  StyletronServer.prototype.constructor = StyletronServer;

  StyletronServer.prototype.injectDeclaration = function injectDeclaration (decl) {
    this.injectionCount++;
    return StyletronCore.prototype.injectDeclaration.call(this, decl);
  };

  StyletronServer.prototype.getStylesheets = function getStylesheets () {
    return cacheToStylesheets(this.cache);
  };

  StyletronServer.prototype.getStylesheetsHtml = function getStylesheetsHtml (className) {
    if ( className === void 0 ) className = 'styletron';

    return generateHtmlString(this.getStylesheets(), className);
  };

  /**
   * Get the CSS string of cache
   * @return {String} The string of CSS
   * @example
   * const styletron = new StyletronServer();
   *
   * styletron.injectDeclaration({prop: 'color', val: 'red'});
   * // → 'c0'
   * styletron.getCss();
   * // → '.c0{color:red}'
   */
  StyletronServer.prototype.getCss = function getCss () {
    return cacheToCss(this.cache);
  };

  StyletronServer.prototype.getInjectionCallCount = function getInjectionCallCount () {
    return this.injectionCallCount;
  };

  return StyletronServer;
}(StyletronCore));

module.exports = StyletronServer;
